#GIT_CMT=b4cbf4b38e931e12c1c3ca9080ad650e7d666fc4
# Copyright(c) 2015, Oracle and/or its affiliates.  All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# Python major version.
%{expand: %%define pyver %(python -c 'import sys;print(sys.version[0:3])')}

# Package version
%global package_version 0.1.0

# Kolla user name and group name (DO NOT CHANGE THESE!)
%global kolla_user      kolla
%global kolla_group     %{kolla_user}

# Docker group name
%global docker_group    docker


Summary:        OpenStack Kolla Deployment
Name:           openstack-kolla
Version:        %{package_version}
Release:    118.el7
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla
Source0: openstack-kolla-0.1.0.tar.bz2
BuildArch:      noarch
BuildRequires:  python                      >= 2.6
BuildRequires:  python-setuptools           >= 0.9.8
BuildRequires:  python-pbr                  >= 1.3.0


%description
OpenStack Kolla meta package


%prep
%setup -q -n %{name}-%{version}


%build
# Generate a temporary pkg-info file to make pbr happy
PKGINFO_NAME=$(sed -n -e '/^name/ s/name\s=\s//p' setup.cfg)
PKGINFO_VERSION=$(sed -n -e '/^version/ s/version\s=\s//p' setup.cfg)
cat >PKG-INFO <<__EOF__
Metadata-Version: 1.1
Name: ${PKGINFO_NAME}
Version: ${PKGINFO_VERSION}
__EOF__

# Build the package
%{__python} setup.py build


%install
%{__python} setup.py install --skip-build --root %{buildroot}

# Create the required directory structures
mkdir -m 0755 -p %{buildroot}/%{_sysconfdir}/kolla
cp -r etc/kolla/* %{buildroot}/%{_sysconfdir}/kolla/
chmod 0600 %{buildroot}/%{_sysconfdir}/kolla/passwords.yml
chmod 0664 %{buildroot}/%{_sysconfdir}/kolla/globals.yml

# Create the Kolla sudo file
mkdir -p %{buildroot}/etc/sudoers.d
_group=%{kolla_group}
cat >%{buildroot}/etc/sudoers.d/%{kolla_user} <<__EOF__
Defaults: %{kolla_user} !requiretty
Cmnd_Alias KOLLA_ADMIN_CMDS = ALL
%{kolla_user} ALL = (root) NOPASSWD: KOLLA_ADMIN_CMDS

Defaults: %${_group} !requiretty
Cmnd_Alias KOLLA_CMDS = /usr/bin/ansible, /usr/bin/ansible-playbook, /bin/ls, /bin/id
%${_group} ALL = (%{kolla_user}) NOPASSWD: KOLLA_CMDS
__EOF__
chmod 0600 %{buildroot}/etc/sudoers.d/%{kolla_user}

mv -f %{buildroot}/%{_datadir}/kolla/ansible/inventory \
      %{buildroot}/%{_datadir}/kolla/ansible/inventory_samples


%clean
rm -rf %{buildroot}


%files
%defattr(-, root, root)
%attr(0444, root, root) %doc LICENSE
%attr(0444, root, root) %doc README.rst



# Package the Kolla development files
%package -n     openstack-kolla-devel
Summary:        OpenStack Kolla development files.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       GitPython                   >= 1.0.1
Requires:       python-gitdb                >= 0.6.4
Requires:       python-pbr                  >= 1.3.0
Requires:       python-jinja2               >= 2.6
Requires:       openstack-kolla-ansible     = %{package_version}


%description -n openstack-kolla-devel
Files used to develop Kolla OpenStack Docker images.


%files -n       openstack-kolla-devel
%exclude %{_datadir}/kolla/ansible
%exclude %{_datadir}/kolla/docs/ansible-deployment.rst
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(0444, root, root) %doc LICENSE
%attr(0444, root, root) %doc README.rst
%attr(-, root, %{kolla_group}) %{_bindir}/kolla-build
%{_datadir}/kolla/
%{python_sitelib}/*



# Package the Kolla dependent files
%package -n     openstack-kolla-ansible
Summary:        OpenStack Kolla Ansible playbooks and supporting files.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       ansible                     >= 1.9.2
Requires:       openstack-kolla             = %{package_version}
Requires:       openstack-kolla-preinstall  = %{package_version}

Requires:       /bin/sed

%description -n openstack-kolla-ansible
Ansible playbooks and support files to deploy Kolla in Docker containers.


%files -n       openstack-kolla-ansible
%exclude %{_datadir}/kolla/docs/[b-z0-9A-Z]*
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(-, root, root) %doc LICENSE
%doc %{_datadir}/kolla/docs/ansible-deployment.rst
%config(noreplace) %{_sysconfdir}/kolla
%attr(-, root, %{kolla_group}) %{_bindir}/kolla-ansible
%{_datadir}/kolla/ansible


%post -n        openstack-kolla-ansible
if test -f /etc/ansible/ansible.cfg && \
   grep -q '^#.*host_key_checking.*False' /etc/ansible/ansible.cfg
then
    sed\
     -i.rpmsaved\
     -e 's/^#.*host_key_checking.*=.*/host_key_checking = False/'\
     /etc/ansible/ansible.cfg
fi



# Package the Kolla utility files
%package -n     openstack-kolla-utils
Summary:        OpenStack Kolla utilities.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       openstack-kolla             = %{package_version}


%description -n openstack-kolla-utils
Utilities for use with Kolla containers.


%files -n       openstack-kolla-utils
%attr(-, root, root) %doc LICENSE
%attr(755, root, root) %{_bindir}/docker-ostk



# Package the Kolla dependent files
%package -n     openstack-kolla-preinstall
Summary:        OpenStack Kolla pre-install configuration.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       docker-engine               >= 1.8.1
Requires:       python-docker-py            >= 1.3.1
Requires:       python-six                  >= 1.9.0

Requires:       sudo
Requires:       /usr/sbin/useradd
Requires:       /usr/sbin/userdel
Requires:       /usr/sbin/groupadd
Requires:       /bin/grep
Requires:       /bin/mkdir
Requires:       /bin/chown


%description -n openstack-kolla-preinstall
Prepare a system for use by OpenStack Kolla deployments.


%files -n       openstack-kolla-preinstall
%attr(-, root, root) %doc LICENSE
%attr(0600, root, root) /etc/sudoers.d/%{kolla_user}
%attr(0755, %{kolla_user}, %{kolla_group}) %dir %{_datadir}/kolla


%pre -n         openstack-kolla-preinstall
if ! grep -q '^#include.*/etc/sudoers.d' /etc/sudoers
then
    echo 'ERROR: /etc/sudoers is NOT including the /etc/sudoers.d files!!' >&2
    echo '       Unable to install'
    exit 1
fi

/usr/sbin/groupadd -f -r %{docker_group}
/usr/sbin/groupadd -f -r %{kolla_group}
if ! grep -q %{kolla_user} /etc/passwd
then
    _uids=($(awk -F: '{print $3}' /etc/passwd))
    _uids_count=${#_uids[@]}
    _uid=200
    _used=true
    while ${_used}
    do
        _uids_copy=(${_uids[@]/${_uid}/})
        if [[ ${#_uids_copy[@]} == ${_uids_count} ]]
        then
            _used=false
            break
        fi
        _uid=$((${_uid} + 1))
    done
    /usr/sbin/useradd\
      -b %{_datadir}\
      -c 'Kolla User'\
      -g %{kolla_group}\
      -G %{docker_group}\
      -M\
      -N\
      -r\
      -u ${_uid}\
      %{kolla_user}
    [[ $? -ne 0 ]] && exit 1
    [[ ! -d ~%{kolla_user} ]] && mkdir -p ~%{kolla_user}
    chown -f %{kolla_user}:%{kolla_group} ~%{kolla_user}
    chmod -f 0750 ~%{kolla_user}
fi
exit 0


%post -n        openstack-kolla-preinstall
if ! test -d ~%{kolla_user}/.ssh
then
    mkdir -p -m 0700 ~%{kolla_user}/.ssh
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh
    [[ $? -ne 0 ]] && exit 1
fi
if ! test -f ~%{kolla_user}/.ssh/authorized_keys
then
    touch ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
    chmod 0600 ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
fi
if test -x /usr/bin/systemctl
then
    systemctl enable docker >/dev/null 2>&1
    systemctl start  docker >/dev/null 2>&1
else
    chkconfig docker on    >/dev/null 2>&1
    service   docker start >/dev/null 2>&1
fi
exit 0



%changelog
* Sat Oct 10 2015 James McCarthy <james.m.mccarthy@oracle.com> - 0.1.0-118.el7
- Bug 21912518: Partial fix, updated haproxy and nova ansible templates (James
  McCarthy)

* Fri Oct 09 2015 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.1.0-117.el7
- fixed nova compute/libvirt iscsi initiator (Vladislav Belogrudov)  
- cinder-volume needs to access /run/lvm from host (Vladislav Belogrudov)  
- Remove dummy swift data vols, bind mount /srv/node into swift_data (Paul Bourke)  
- correct cinder template: volume name template, my ip and default volume type (Vladislav Belogrudov)  
- increase mysqlcluster limits (Vladislav Belogrudov)

* Thu Oct 08 2015 Paul Bourke <paul.bourke@oracle.com> - 0.1.0-116.el7
- Add env-file functionality to docker-ostk (Paul Bourke)

* Wed Oct 07 2015 Paul Bourke <paul.bourke@oracle.com> - 0.1.0-115.el7
- Remove accidental debug in docker-ostk (Paul Bourke)

* Wed Oct 07 2015 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.1.0-114.el7
- Revert "adding patch mechanism back in." (Vladislav Belogrudov)  
- use database as session backend for horizon (avoid murano cookies problem) (Vladislav Belogrudov)  
- use stable/kilo for murano (Vladislav Belogrudov)  
- Refactor docker-ostk, parse docker tag from globals.yml (Paul Bourke)

* Tue Oct 06 2015 Paul Bourke <paul.bourke@oracle.com> - 0.1.0-113.el7
- Parse registry from /etc/kolla/globals.yml if exists (Paul Bourke)

* Tue Oct 06 2015 Paul Bourke <paul.bourke@oracle.com> - 0.1.0-112.el7
- Auto mount cwd as /data in the docker-ostk container (Paul Bourke)  
- add ha queues to rabbitmq, re-factor code (hide rabbitmqctl commands in container) (Vladislav Belogrudov)  
- Rename section name for consistency (James McCarthy)  
- Add --rm to docker-ostk ARGS (Paul Bourke)  
- Update haproxy configuration for swift_proxy_server (James McCarthy)  
-   Tokenised logging levels in templates (Mick Thompson)

* Mon Oct 05 2015 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.1.0-111.el7
- mysqlcluster is active/active by design - don't make backups in haproxy config (Vladislav Belogrudov)  
- use bigger timeout for rabbitmq to avoid pollution of logs (Vladislav Belogrudov)  
- stage starting of rabbitmq servers to avoid race condition while clustering (similar to kolla upstream but we don't sleep and use sudo inside of container (Vladislav Belogrudov)  
- Added the check to make sure sudoers.d gets included (Wiekus Beukes)

* Fri Oct 02 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1.0-110.el7
- Renamed -tools to -utils (Wiekus Beukes)  
- Bug 21929979: Added in directory creation (James McCarthy)

* Fri Oct 02 2015 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.1.0-19.el7
- fix murano configuration according to generated sample (Vladislav Belogrudov)

* Fri Oct 02 2015 Kevin Loughnane <kevin.loughnane@oracle.com> - 0.1.0-18.el7
- Bug 21935249:  add qemu-kvm package to nova-compute OL build-from-source (Kevin Loughnane)  
- use inhouse version of ansible 2 (Vladislav Belogrudov)  
- Bug 21931534: add nfs-utils package to nova-base OL build-from-source (Kevin Loughnane)

* Wed Sep 30 2015 Borne Mace <borne.mace@oracle.com> - 0.1.0-17.el7
- changed config_strategy in globals.yml to COPY_ALWAYS (Borne Mace)  
- pre-start murano-api while bootstrapping to import io.murano.zip (Vladislav Belogrudov)  
- check bootstrap result for murano (Vladislav Belogrudov)  
- Updated keystone haproxy config to balance based on source ip (James McCarthy)  
- need to pack css after murano install (Vladislav Belogrudov)  
- config-swift-object.sh not needed (James McCarthy)  
- Add missing core library to murano (Mick Thompson)

* Tue Sep 29 2015 Mark Duggan <mark.duggan@oracle.com> - 0.1.0-16.el7
- adding patch mechanism back in. (Mark Duggan)  
- added hyperv mechanism and config option (Vladislav Belogrudov)  
- debugging buils issue (Mark Duggan)  
- changed Dockerfile to include patching mechanism (Mark Duggan)  
- Install oslo.utils in openstack-base (Paul Bourke)  
- ncreasing logginf to "info" level (Mark Duggan)  
- Remove cinder specific env var from docker-ostk (Paul Bourke)  
- Fix supplying of OS_* env vars to docker-ostk (Paul Bourke)  
- heat incorrectly saved result in database_user variable (Vladislav Belogrudov)  
- Install e2fsprogs in nova-base (Paul Bourke)  
- Update help message to use new utils image in docker-ostk (Paul Bourke)  
- Update docker-ostk script to use new utils image symlink (Paul Bourke)

* Fri Sep 25 2015 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.1.0-15.el7
- add murano to haproxy config (Vladislav Belogrudov)  
- add ndb migration to murano (Vladislav Belogrudov)  
- Bug 21880645: ImportError: No module named keystonemiddleware.auth_token - include keystonemiddleware (jamesmmccarthy)  
- ansible 2.0 container needs newer openstack clients than kilo used elsewhere (Vladislav Belogrudov)  
- Symlink openstack-base to provide a more usable name (Paul Bourke)  
- add -y to yum install for nfs-utils (Kevin Loughnane)  
- add -y to yum install for nfs-utils (Kevin Loughnane)  
- Fixed logging issue in ovs-vswitchd container.  Output now available from "docker logs" (Mark Duggan)  
- Bug 21836881: include the zfssaiscsi  ZFS iscsi Driver in Cinder (Kevin Loughnane)  
- Bug 21836881: include the zfssaiscsi  ZFS iscsi Driver in Cinder (Kevin Loughnane)  
- added mount point to glance-api for nfs storage (Vladislav Belogrudov)  
- Add .vagrant dir to .gitignore (Paul Bourke)  
- Add missing Swift services, also ansible configuration (jamesmmccarthy)

* Wed Sep 23 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1.0-14.el7
- - Added the kolla-tools package (Wiekus Beukes)  
- Add docker-ostk to setup.cfg (Paul Bourke)  
- add sample external vlan config (Vladislav Belogrudov)  
- Pin openstack-client to 1.0.4 in openstack-base (Paul Bourke)  
- Bug 21887461: add nfs-utils to ol-openstack-cinder-base because ZFS NFS Driver needs it (Kevin Loughnane)  
- remove l2population feature from neutron since it breaks more than creates (up to customer to enable it) (Vladislav Belogrudov)  
- Add a simple wrapper script to use ostk clients via Docker (Paul Bourke)  
- Add openstack-base image containing all ostk client tools (Paul Bourke)  
- don't use sudo for root helper in neutron to avoid kill/restart cycles (Vladislav Belogrudov)  
- disable swift by default (Borne Mace)  
- don't create br-ex on compute nodes and don't put interface mappings inot ml2 config for such hosts (Vladislav Belogrudov)  
- fix heat configuration to work with kilo release according to official OpenStack installation guide (Vladislav Belogrudov)  
- use openstackclient suitable for kilo (Vladislav Belogrudov)  
- Bug 21876899: add privileged:True to Starting-Openvswitch-db-container Ansible Task (Kevin Loughnane)

* Mon Sep 21 2015 Borne Mace <borne.mace@oracle.com> - 0.1.0-13.el7
- disabled mariadb in properties.  enabled cinder and swift by default in properties settings. (Borne Mace)  
- fix cinder-volume code to use targetcli (Vladislav Belogrudov)  
- need access to host's /lib/modules for cinder (Vladislav Belogrudov)  
- bootstrapping in wrong place - should only be in heat-api (Vladislav Belogrudov)  
- use sudo instead of su for heat-api bootstrapping code (Vladislav Belogrudov)

* Mon Sep 21 2015 Paul Bourke <paul.bourke@oracle.com> - 0.1.0-12.el7
- Build it

* Thu Sep 17 2015 Paul Bourke <paul.bourke@oracle.com> - 0.1.0-11.el7
- Add missing libvirt section to nova.conf (Paul Bourke)  
- Fix 'docker log' functionality for keystone (Paul Bourke)

* Thu Sep 17 2015 Paul Bourke <paul.bourke@oracle.com> - 0.1.0-10.el7
- Revert "Use internal rpm for Ansible 2.0 alpha" (Paul Bourke)  
- Added OL6 support (Wiekus Beukes)  
- Use internal rpm for Ansible 2.0 alpha (Paul Bourke)  
- rename ndb to mysqlcluster everywhere (Vladislav Belogrudov)  
- add missing dnsmasq to neutron dhcp agent (Vladislav Belogrudov)  
- added ipset to openvswitch_agent container (Vladislav Belogrudov)

* Tue Sep 15 2015 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.1.0-9.el7
- properly added openvswitch to neutron containers (fixed build issues) (Vladislav Belogrudov)  
- Adding Oracle FS1 driver tarball and DOckerfile changes to integrate driver (Mark Duggan)  
- Move swift build to stable/kilo (Paul Bourke)  
- Move nova build to stable/kilo (Paul Bourke)  
- Move glance build to stable/kilo (Paul Bourke)  
- Story OPENSTACK-289: Swift ProxyServer should run on ControlNode (Kevin Loughnane)  
- no need to install openvswitch in neutron-openvswitch-agent because it is in neutron-base (Vladislav Belogrudov)  
- add missing openvswitch to neutron (Vladislav Belogrudov)  
- Enable nova-libvirt to be updated (Steven Dake)  
- Make nova use a data container (Steven Dake)  
- add openvswitch to nova-compute (Vladislav Belogrudov)  
- Bug 21669646: NeutronServer shoudl run on ControlNode (Kevin Loughnane)  
- Add vagrant-generated files to gitignore (Martin André)  
- Change default ansible_ssh_user to "kolla" (Paul Bourke)  
- Use internal RPM for python pip in base (Paul Bourke)  
- Make novncproxy work on from source installs (Steven Dake)  
- use ndb/2015.1.1 branch for neutron code to contain all numerous migrations combined (Vladislav Belogrudov)  
- Revert "Added migration script to neutron-base template." (Vladislav Belogrudov)  
- Revert "use 2015.1.1 ndb patches for neutron" (Vladislav Belogrudov)

* Fri Sep 11 2015 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.1.0-8.el7
- Source type nova compute container misses qemu-img on VM boot (Vladislav
  Belogrudov)

* Thu Sep 10 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1.0-7.el7
- Changed Useradd to not create the home dir anymore but to create it discretely if it does not exist (Wiekus Beukes)  
- added the ansible command to the sudoers list for the kolla user as we need it to perform the ssh check / ping (Borne Mace)

* Thu Sep 10 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1.0-6.el7
- Allowthe kolla home dir to exist at install time (Wiekus Beukes)  
- replace mariadb_port with database_port for ndb (Vladislav Belogrudov)  
- First keepalived container is started with wrong priority (Vladislav Belogrudov)  
- Ansible does not wait for virtual IP to appear (Vladislav Belogrudov)  
- run haproxy on controllers (Vladislav Belogrudov)

* Wed Sep 09 2015 Paul Bourke <paul.bourke@oracle.com> - 0.1.0-5.el7
- Change globals.yml defaults to oracle (Paul Bourke)  
- Cleanup murano merge conflict markers (Paul Bourke)

* Tue Sep 08 2015 Mick Thompson <michael.a.thompson@oracle.com> - 0.1.0-4.el7
- Enabled murano in all.yml (Mick Thompson)  
- Add ansible support for Murano (Mick Thompson)  
- Add database nodes to Vagrantfile for ndb (Paul Bourke)  
- Add missing node types to Vagrantfile (Paul Bourke)  
- ndb register tasks should only run on ndb-mysql hosts (Vladislav Belogrudov)  
- fix distributed mode for ndb cluster (Vladislav Belogrudov)  
- Add missing Swift services, also ansible configuration (James McCarthy)  
- Add rsyncd image and related Ansible for Swift (Paul Bourke)  
- add [database] hosts to ansible play for ndb (Vladislav Belogrudov)  
- replace mariadb with ndb-mysql nodes in haproxy ansible (Vladislav Belogrudov)  
- Gather facts from the hosts before using them (Sam Yaple)  
- add log folder for supervisord. Once we have supervisord rpm this fix can be reverted (Vladislav Belogrudov)  
- Correct name of source archive if reference contains '/' (Vladislav Belogrudov)  
- Properly check failed status (Sam Yaple)  
- Check exit status of bootstrap containers (Vladislav Belogrudov)  
- check exit status of ndb bootstrap container (Vladislav Belogrudov)  
- Fix rabbitmq perms (Sam Yaple)  
- Copy config to /etc/kolla rather than symlink in Vagrantfile (Paul Bourke)

* Fri Sep 04 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1.0-3.el7
- Fixed issue where post would sometime error exiting Changed the SSH dir create to be post rather then forcefully laying it down Change the Ansible config file to disable host key checking (Wiekus Beukes)  
- Set cinder auth_strategy to keystone explicitely (Vladislav Belogrudov)  
- fix 'boostrap' message of ndb cluster (Vladislav Belogrudov)  
- fix typo in cinder manage command (introduced by sudo fix) (Vladislav Belogrudov)  
- Allow arbitrary source archive name to be imported into Dockerfile (Vladislav Belogrudov)  
- Revert "fix building novnc from git clone" (Vladislav Belogrudov)

* Thu Sep 03 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1.0-2.el7
- Removed the extraneous Release: tags for autobuild to generate the correct rpm versions (Wiekus Beukes)  
- Fixed file/dir permission and deps (Wiekus Beukes)  
- use 2015.1.1 ndb patches for neutron (Vladislav Belogrudov)  
- add second host to samle [network] for haproxy (Vladislav Belogrudov)

* Wed Sep 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Initial release

